@@ -291,10 +291,18 @@ class BackupConfig(DataClassExtensions):
         Returns:
             The formatted .tgz filename.
         """
-        now: datetime = datetime.datetime.now(datetime.timezone.utc).replace(
-            microsecond=0
+        # datetime's ISO format includes the ':' separator for the `hours:minutes:seconds`.
+        # Since we're using this format in the filename of the backup, the backup filename
+        # will include the ':' character.
+        # Tools like `tar` (by default) expects files with ':' in the name to be a remote
+        # resouces. To avoid this issue, we remove all ':'.
+        now: str = (
+            datetime.datetime.now(datetime.timezone.utc)
+            .replace(microsecond=0)
+            .isoformat()
+            .replace(":", "")
         )
-        return f"{app_name.upper()}_{backup_name.upper()}_{now.isoformat()}.tgz"
+        return f"{app_name.upper()}_{backup_name.upper()}_{now}.tgz"
 
     def __rolling_backup_deletion(self, backup_dir: Path):
         """Delete old backups, will only keep the most recent backups.
